@@ -29,8 +29,8 @@
 
 #define HEIGHT   120
 #define WIDTH    90
-#define KEY      6146     /* Some nice number */
-#define SHMSIZE  40       /* Size of shared memory */
+//#define KEY      6146     /* Some nice number */
+//#define SHMSIZE  40       /* Size of shared memory */
 
 /*
  * Callbox class
