@@ -45,7 +45,7 @@ const char *helpText[NUM_TOPICS] = {
 "\n\
 Twpsk is a sound card program that allows you to transmit and receive \
 PSK31, the digital mode developed by Peter, G3PLX. It has a \
-Graphical User Interface (GUI) which uses the Motif libraries. \n\
+Graphical User Interface (GUI) which uses the Motif or lessTiff libraries. \n\
 \n\
 The GUI consists of the main window and several other windows that you \
 pop up as needed. The main window has five sections: a Menu Bar, \
@@ -179,6 +179,19 @@ it will be a darker shade of gray. New data is displayed at the bottom, and \
 older data runs off the top of the display. Since this is Linux, the \
 waterfall flows up hill. \n\
 \n\
+Flow Up \n\
+Since the day twpsk was written, the waterfall always flowed up.  And why \
+not?  After all, this is linux.  If you prefer to have the waterfall flow \
+down, deselect this toggle button. \n\
+\n\
+Local Caps \n\
+With PSK's variable length Unicode, it is best to send lower case characters \
+because lower case codes are shorter than their upper case equivalent.  \
+However, some people find it easier to read text printed in upper case. \
+When this button is sellected, all received and transmitted text will be \
+displayed in upper case.  However, the transmitted characters will be sent in \
+the case they were typed - upper or lower. \n\
+\n\
 Open Decoder \n\
 This button opens a secondary receiver window at the current receive \
 frequency. This is an easy way to put the current signal into a \
@@ -194,7 +207,7 @@ easier to \"press\" them from the keyboard. See the Accelerator Keys section \
 for more information. \n\
 \n\
 The scan will stop when a PSK signal is detected. A scan will also stop when \
-it reaches 0.0 Hz. or the maximum frequency, 3000 Hz. The display is gray for \
+it reaches 0.0 Hz. or the maximum frequency, 4000 Hz. The display is gray for \
 frequencies less than 0.0 Hz, and above the maximum frequency. \n\
 \n\
 NOTE: Once you start a scan, pressing any of these buttons, \
@@ -370,7 +383,7 @@ This text field shows the center receive frequency. If you click in this \
 window, you can edit the number to select a desired frequency. \n\
 \n\
 NOTE: While the window is selected, the AFC is disabled. To indicate \
-that the AFC is disabled, the text changes from black to white. \
+that the AFC is disabled, the background changes to a darker color. \
 Clicking outside the Rx Freq will enable the AFC again. \n\
 \n\
 NOTE: The text is also white during a scan. It returns to black when a \
