@@ -22,6 +22,10 @@
 #ifndef INCLUDED_TWPSKCB_H
 #define INCLUDED_TWPSKCB_H
 
+#define KEY 6146
+// in GUI.h #define MAXCALL 12
+#define SHMSIZE 2 * MAXCALL
+
 #include <Xm/XmP.h>
 
 class TwpskCB 
@@ -29,6 +33,12 @@ class TwpskCB
 
    private:
 
+      //struct callsStruct
+      //{
+         //char inCall[MAXCALL];      /* note names are reversed */
+         //char outCall[MAXCALL];
+      //} *calls;
+
       Position x, y;
 
    public:
